package cn.efunbox.audio.controller;

import cn.efunbox.audio.entity.Audio;
import cn.efunbox.audio.entity.Device;
import cn.efunbox.audio.service.AudioService;
import cn.efunbox.audio.service.DeviceService;
import cn.efunbox.audio.util.ApiCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * Created by yao on 17-9-26.
 */
@RestController
@Slf4j
@RequestMapping(value = "/audio")
public class AudioController {

    @Autowired
    AudioService audioService;

    @RequestMapping(value = "/search" ,method = RequestMethod.POST)
    public Map Search(HttpServletRequest request){
        Map map = new HashMap<>();
        String name = request.getParameter("name");
        String album = request.getParameter("album");
        if(name==null && album==null){
            map.put("code", ApiCode.PARAMETER_ERROR.getCode());
            map.put("msg", ApiCode.PARAMETER_ERROR.getMessage());
            return map;
        }
        List<Audio> list = null;
        if(name!=null && name.length()>0  && album!=null && album.length()>0)
            list = audioService.SearchByNameAlbum(name, album);
        else if(name!=null && name.length()>0)
            list = audioService.SearchByName(name);
        else
            list = audioService.SearchByAlbum(album);

        if(list==null || list.size()<1){
            map.put("code", ApiCode.NOT_FOUND.getCode());
            map.put("msg", ApiCode.NOT_FOUND.getMessage());
            return map;
        }

        Random random = new Random();
        int r = Math.abs(random.nextInt())%list.size();
        map.put("code", ApiCode.OK.getCode());
        map.put("data", list.get(r));

        return map;
    }

    @RequestMapping(value = "/insert", method = RequestMethod.POST)
    public Map Insert(HttpServletRequest request){
        Map map = new HashMap<>();
        String album = request.getParameter("album");
        String lesson = request.getParameter("lesson");
        String name = request.getParameter("name");
        String url = request.getParameter("url");
        if(album==null || name==null && url==null){
            map.put("code", ApiCode.PARAMETER_ERROR.getCode());
            map.put("msg", ApiCode.PARAMETER_ERROR.getMessage());
            return map;
        }

        Audio audio = new Audio();
        audio.setAlbum(album);
        if(lesson!=null && lesson.length()>0)
            audio.setLesson(Integer.valueOf(lesson));
        audio.setName(name);
        audio.setUrl(url);
        audio.setCreated(new Date());
        audio = audioService.Insert(audio);

        map.put("code", ApiCode.OK.getCode());
        map.put("data", audio);
        return map;
    }

}
